%global pypi_name jaraco.envs
%global pkg_name jaraco-envs

# Not all test dependencies are available yet
%bcond_with tests
%bcond_with docs

Name:           python-%{pkg_name}
Version:        2.3.0
Release:        %mkrel 2
Summary:        Classes for orchestrating Python (virtual) environments
Group:          Development/Python
License:        MIT
URL:            https://pypi.org/project/jaraco.envs
Source0:        %pypi_source
BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  python3dist(setuptools-scm[toml])
BuildRequires:  python3dist(wheel)
BuildRequires:  python3dist(tox)
BuildRequires:  python3dist(virtualenv)

%if %{with tests}
BuildRequires:       python3dist(pytest)
BuildRequires:       python3dist(pytest-cov)
BuildRequires:       python3-path
BuildRequires:       python3dist(pytest-checkdocs)
BuildRequires:       python3dist(pytest-flake8)
BuildRequires:       python3dist(pytest-black-multipy)
%endif


%description
Classes for orchestrating Python (virtual) environments.

%package -n     python3-%{pkg_name}
Summary:        %{summary}
Group:          Development/Python
Requires:       python3-path
Requires:       python3-jaraco

%description -n python3-%{pkg_name}
Classes for orchestrating Python (virtual) environments.

%if %{with docs}
%package -n python-%{pkg_name}-doc
Summary:        jaraco-envs documentation
Group:          Development/Python
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(jaraco-packaging)
BuildRequires:  python3dist(rst-linker)

%description -n python-%{pkg_name}-doc
Documentation for jaraco-envs
%endif

%prep
%autosetup -n jaraco.envs-%{version}
# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

# Remove path dependency as to not
# automatically generate requires metadata.
# path does not provide the python3dist namespace
sed -i '/path/d' setup.cfg

%build
%pyproject_wheel
%if %{with docs}
# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%pyproject_install
%if %{with tests}
%check
%pytest
%endif

%files -n python3-%{pkg_name}
%license LICENSE
%doc README.rst
# These excludes are provided by python3-jaraco
%{python3_sitelib}/jaraco/envs*
%{python3_sitelib}/jaraco/__pycache__/envs*
%{python3_sitelib}/jaraco.envs-%{version}.dist-info

%if %{with docs}
%files -n python-%{pkg_name}-doc
%doc html
%license LICENSE
%endif


%changelog
* Thu Aug 18 2022 papoteur <papoteur> 2.3.0-2.mga9
+ Revision: 1878576
- remove auto BR

* Sun Apr 10 2022 guillomovitch <guillomovitch> 2.3.0-1.mga9
+ Revision: 1848607
- new version 2.3.0

* Tue Mar 29 2022 umeabot <umeabot> 2.2.0-3.mga9
+ Revision: 1832834
- Mageia 9 Mass Rebuild

* Thu Feb 24 2022 mrambo3501 <mrambo3501> 2.2.0-2.mga9
+ Revision: 1784287
- rebuild for python-3.10

* Sun Dec 12 2021 guillomovitch <guillomovitch> 2.2.0-1.mga9
+ Revision: 1761623
- new version 2.2.0

* Sun Mar 21 2021 guillomovitch <guillomovitch> 2.1.1-1.mga9
+ Revision: 1706725
- rebuild for python 3.9

* Thu Mar 11 2021 guillomovitch <guillomovitch> 2.1.0-1.mga9
+ Revision: 1701511
- imported package python-jaraco-envs

